==> jc-1.4.0.tar.gz: soot/util/dot/DotGraphCommand.h <==
// public class soot.util.dot.DotGraphCommand

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6fd8e80cbbe389c0 soot_util_dot_DotGraphCommand

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphCommand_H_
#define _JC_soot_util_dot_DotGraphCommand_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphCommand$sub_refs	_jc_soot_util_dot_DotGraphCommand$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphCommand$sub_nonrefs	_jc_soot_util_dot_DotGraphCommand$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphCommand$refs	_jc_soot_util_dot_DotGraphCommand$refs;
typedef struct _jc_soot_util_dot_DotGraphCommand$nonrefs	_jc_soot_util_dot_DotGraphCommand$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphCommand$object	_jc_soot_util_dot_DotGraphCommand$object;

typedef const struct _jc_soot_util_dot_DotGraphCommand$vmethods	_jc_soot_util_dot_DotGraphCommand$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphCommand$vtable	_jc_soot_util_dot_DotGraphCommand$vtable;
typedef const struct _jc_soot_util_dot_DotGraphCommand$vtype	_jc_soot_util_dot_DotGraphCommand$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphCommand$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_util_dot_DotGraphCommand$method$render$d3bab9d003cfd984(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_io_OutputStream$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphCommand$method_info$render$d3bab9d003cfd984;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphCommand$vmethods {
	void	(*render$d3bab9d003cfd984)(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_io_OutputStream$object *, jint);
};

// Vtable
struct _jc_soot_util_dot_DotGraphCommand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphCommand$vmethods	soot_util_dot_DotGraphCommand;
};

// Vtype
struct _jc_soot_util_dot_DotGraphCommand$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphCommand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphCommand$sub_refs {
	struct _jc_java_lang_String$object	*command;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphCommand$refs {
    _jc_soot_util_dot_DotGraphCommand$sub_refs	soot_util_dot_DotGraphCommand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphCommand$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphCommand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphCommand$sub_nonrefs	soot_util_dot_DotGraphCommand;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphCommand$object {
	_jc_soot_util_dot_DotGraphCommand$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphCommand$vtype	*vtype;
	_jc_soot_util_dot_DotGraphCommand$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphCommand$vtype _jc_soot_util_dot_DotGraphCommand$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphCommand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphCommand$class_object;

#endif	/* _JC_soot_util_dot_DotGraphCommand_H_ */

==> jc-1.4.6.tar.gz: soot/util/dot/DotGraphCommand.h <==
// public class soot.util.dot.DotGraphCommand

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6fd8e80cbbe389c0 soot_util_dot_DotGraphCommand

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphCommand_H_
#define _JC_soot_util_dot_DotGraphCommand_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphCommand$sub_refs	_jc_soot_util_dot_DotGraphCommand$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphCommand$sub_nonrefs	_jc_soot_util_dot_DotGraphCommand$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphCommand$refs	_jc_soot_util_dot_DotGraphCommand$refs;
typedef struct _jc_soot_util_dot_DotGraphCommand$nonrefs	_jc_soot_util_dot_DotGraphCommand$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphCommand$object	_jc_soot_util_dot_DotGraphCommand$object;

typedef const struct _jc_soot_util_dot_DotGraphCommand$vmethods	_jc_soot_util_dot_DotGraphCommand$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphCommand$vtable	_jc_soot_util_dot_DotGraphCommand$vtable;
typedef const struct _jc_soot_util_dot_DotGraphCommand$vtype	_jc_soot_util_dot_DotGraphCommand$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphCommand$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_dot_DotGraphCommand$method$render$d3bab9d003cfd984(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphCommand$method_info$render$d3bab9d003cfd984;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphCommand$vmethods {
	void	(*render$d3bab9d003cfd984)(_jc_env *, struct _jc_soot_util_dot_DotGraphCommand$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_dot_DotGraphCommand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphCommand$vmethods	soot_util_dot_DotGraphCommand;
};

// Vtype
struct _jc_soot_util_dot_DotGraphCommand$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphCommand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphCommand$sub_refs {
	struct _jc_java_lang_String$object	*command;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphCommand$refs {
    _jc_soot_util_dot_DotGraphCommand$sub_refs	soot_util_dot_DotGraphCommand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphCommand$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphCommand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphCommand$sub_nonrefs	soot_util_dot_DotGraphCommand;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphCommand$object {
	_jc_soot_util_dot_DotGraphCommand$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphCommand$vtype	*vtype;
	_jc_soot_util_dot_DotGraphCommand$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphCommand$vtype _jc_soot_util_dot_DotGraphCommand$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphCommand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphCommand$class_object;

#endif	/* _JC_soot_util_dot_DotGraphCommand_H_ */
